'use strict';
import * as echarts from 'echarts';
export var PyzChartsEventType;
(function (PyzChartsEventType) {
    PyzChartsEventType["click"] = "click";
    PyzChartsEventType["dblclick"] = "dblclick";
    PyzChartsEventType["mousedown"] = "mousedown";
    PyzChartsEventType["mousemove"] = "mousemove";
    PyzChartsEventType["mouseup"] = "mouseup";
    PyzChartsEventType["mouseover"] = "mouseover";
    PyzChartsEventType["mouseout"] = "mouseout";
    PyzChartsEventType["globalout"] = "globalout";
    PyzChartsEventType["contextmenu"] = "contextmenu";
    PyzChartsEventType["resize"] = "resize";
    PyzChartsEventType["init"] = "init";
})(PyzChartsEventType || (PyzChartsEventType = {}));
export const PyzChartsEvents = [
    'click',
    'dblclick',
    'mousedown',
    'mousemove',
    'mouseup',
    'mouseover',
    'mouseout',
    'globalout',
    'contextmenu'
];
export const PyzCharts = {
    //template: `<div :id="idName" :class="{[className]: true}" class="PE-Charts"></div>`,
    name: "PyzCharts",
    props: {
        option: {
            type: Object,
            default: () => { return {}; },
        },
        watchRenderDeeper: {
            type: Object,
            default: null,
        },
        jsonMap: {
            type: Object,
            default: null,
        },
        mapName: {
            type: String,
            default: "PYZ",
        }
    },
    data() {
        return {
            tag: 'div',
            styled: `height:100%; width: 100%;`,
            ABCD: ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J'],
            abcd: ['a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j'],
            className: 'PE-Charts',
            idName: 'PE-Charts-ID',
            ectp: null,
        };
    },
    created() {
        this.initClassName();
    },
    mounted() {
        this.$nextTick(() => { setTimeout(() => { this.init(this.$props.option); }); });
    },
    render(createElement) {
        return createElement(this.tag, { attrs: { id: this.idName, class: this.className, style: this.styled, } });
    },
    destroyed() {
        this.removeResize();
        this.$destroy();
    },
    watch: {
        option(val) {
            this.initECharts(val);
        },
        watchRenderDeeper() {
            this.$forceUpdate();
        },
    },
    methods: {
        init(val) {
            this.initECharts(val);
        },
        initClassName() {
            this.ABCD.forEach(() => {
                this.className += `${this.ABCD[parseInt(String(Math.random() * 10))]}${parseInt(String(Math.random() * 10))}`;
                this.idName += `${this.abcd[parseInt(String(Math.random() * 10))]}${parseInt(String(Math.random() * 10))}`;
            });
        },
        // @Params val: option interface
        initECharts(val) {
            if (this.ectp) {
                this.ectp.clear();
                this.ectp.setOption(val);
            }
            else {
                let ecDom = document.querySelector(`.${this.className}`);
                if (ecDom && this.$props.jsonMap) { // 防止引入生命周期 NULL
                    echarts.registerMap(this.$props.mapName, JSON.parse(JSON.stringify(this.$props.jsonMap)));
                    this.ectp = echarts.init(ecDom);
                    this.ectp.clear();
                    this.$emit(PyzChartsEventType.init, this.ectp); // 回传 ECharts 实例
                    this.ectp.setOption(val);
                    this.registryEchartsEvents(this.ectp);
                }
                else if (ecDom) {
                    this.ectp = echarts.init(ecDom);
                    this.ectp.clear();
                    this.$emit(PyzChartsEventType.init, this.ectp); // 回传 ECharts 实例
                    this.ectp.setOption(val);
                    this.registryEchartsEvents(this.ectp);
                }
            } //this.ectp.dispose();
        },
        // @Params val Events List
        registoryResize(target) {
            window.addEventListener(PyzChartsEventType.resize, this.rel, true);
        },
        // @Parmas Event BLO
        rel() {
            this.ectp.resize();
        },
        // @Remote Events
        removeResize() {
            window.removeEventListener(PyzChartsEventType.resize, this.rel, true);
        },
        // @Registry Events
        registryEchartsEvents(target) {
            if (target) {
                let defaultEvent = PyzChartsEvents;
                this.registoryResize();
                defaultEvent.forEach((item) => {
                    target.on(item, (params) => {
                        this.$emit(item, params);
                    });
                });
            }
        }
    },
};
